polylib: Operations on unions of polyhedra
==========================================

Description
-----------

The Polyhedral Library (PolyLib for short) operates on objects made up
of unions of polyhedra of any dimension. polylib is a C library.

License
-------

GPL v3


Upstream Contact
----------------

-  https://groups.google.com/forum/#!forum/isl-development

